/*
 * Titrax preferences subroutines
 *
 * $Id: titraxPref.c,v 1.3 1997/11/23 20:08:59 ga58 Exp ga58 $
 *
 * $Log: titraxPref.c,v $
 * Revision 1.3  1997/11/23 20:08:59  ga58
 * *** empty log message ***
 *
 * Revision 1.2  1997/11/15 17:59:29  ga58
 * *** empty log message ***
 *
 * Revision 1.1  1997/11/14 17:51:04  ga58
 * Initial revision
 *
 */

#pragma pack(2)

#include <Common.h>
#include <System/SysAll.h>
#include <System/Graffiti.h>
#include <UI/UIAll.h>
#include <UI/UIGlobals.h>

#include "titraxAll.h"

typedef struct {
  /* this are the record-indices in the database */
  UInt running[MAXSLOT];
  UInt elapsed[MAXSLOT];
  UInt startedAt[MAXSLOT];
  UInt text[MAXSLOT];
  UInt note[MAXSLOT];
  /* global vars which must be saved */
  Int editedSlot;
  Int editedNoteSlot;
  Int currentView;
  ULong lastCall;
  Int shiftSlot[MAXSLOT];
  ULong inc;
  Boolean track[MAXSLOT];
} TitraxPreferenceType;

static VoidHand prefHand;
static TitraxPreferenceType* prefP;

#define titraxVersionNum 24

void 
CreatePrefs(void)
{
  prefHand = MemHandleNew(sizeof(TitraxPreferenceType));
  ErrFatalDisplayIf(prefHand == 0, "Out of memory for preferences.");

  prefP = (TitraxPreferenceType*)MemHandleLock(prefHand);
}

Boolean
ReadPrefs(void)
{
  return PrefGetAppPreferencesV10((ULong)titraxAppType, titraxVersionNum, prefP, sizeof(TitraxPreferenceType));
}

void
WritePrefs(void)
{
  PrefSetAppPreferencesV10((ULong)titraxAppType, titraxVersionNum, prefP, sizeof(TitraxPreferenceType));
}

void
ClearPrefs(void)
{
  Int i;

  prefP->editedSlot = noSlotActive;
  prefP->editedNoteSlot = noSlotActive;
  prefP->currentView = mainForm;
  prefP->lastCall = TimGetSeconds();
  prefP->inc = 60;

  for(i = 0; i < MAXSLOT; i++) {
	 prefP->shiftSlot[i] = noSlotActive;
	 prefP->track[i] = false;
  }
}

void
DeletePrefs()
{
  if (MemHandleUnlock(prefHand) != 0)
	 return;
  if (MemHandleFree(prefHand) != 0)
	 return;
}

Int
EditedSlot(void)
{
  return prefP->editedSlot;
}

void
SetEditedSlot(Int no)
{
  prefP->editedSlot = no;
}

Int
EditedNoteSlot(void)
{
  return prefP->editedNoteSlot;
}

void
SetEditedNoteSlot(Int no)
{
  prefP->editedNoteSlot = no;
}

Int
CurrentView(void)
{
  return prefP->currentView;
}

void
SetCurrentView(Int view)
{
  prefP->currentView = view;
}

ULong
LastCall(void)
{
  return prefP->lastCall;
}

void
SetLastCall(ULong call)
{
  prefP->lastCall = call;
}

Int
ShiftSlot(Int no)
{
  return prefP->shiftSlot[no];
}

void
SetShiftSlot(Int no, Int val)
{
  prefP->shiftSlot[no] = val;
}

UInt
RunningRecIdx(Int no)
{
  return prefP->running[no];
}

void
SetRunningRecIdx(Int no, UInt idx)
{
  prefP->running[no] = idx;
}

UInt
ElapsedRecIdx(Int no)
{
  return prefP->elapsed[no];
}

void
SetElapsedRecIdx(Int no, UInt idx)
{
  prefP->elapsed[no] = idx;
}

UInt
StartedAtRecIdx(Int no)
{
  return prefP->startedAt[no];
}

void
SetStartedAtRecIdx(Int no, UInt idx)
{
  prefP->startedAt[no] = idx;
}

UInt
TextRecIdx(Int no)
{
  return prefP->text[no];
}

void
SetTextRecIdx(Int no, UInt idx)
{
  prefP->text[no] = idx;
}

UInt
NoteRecIdx(Int no)
{
  return prefP->note[no];
}

void
SetNoteRecIdx(Int no, UInt idx)
{
  prefP->note[no] = idx;
}

ULong
Increment(void)
{
  return prefP->inc;
}

void
SetIncrement(ULong val)
{
  prefP->inc = val;
}

Boolean
Track(Int no)
{
  return prefP->track[no];
}

void
SetTrack(Int no, Boolean val)
{
  prefP->track[no] = val;
}
